Learn R Programming

restaurant (version 0.1.0)

restaurant: Restaurants data set

Description

This provides a record linkage data set with information about different restaurants.

Usage

restaurant

Arguments

Format

A data frame with 16 variables: id, name, address, city, phone, type, class

This data set includes 533 restaurants from the Fodors database and 331 records from the Zagat database. It is appropriate for performing various types of record linkage and can be assessed by standard record linkage methods.

Examples

Run this code
# NOT RUN {
head(restaurant)
dim(restaurant)

# }

Run the code above in your browser using DataLab