A data frame with 3 variables: class, id1, id2
This data set includes the matched record pairs based on ID from the Zagats and Fodors data sets.
This data set can be used to evaluate the performance of record linkage methods performed on the Zagats and Fodors data sets.