A data frame with 16 variables: id, name, address, city, phone, type, class
This data set includes 533 restaurants from the Fodors database and 331 records from the Zagat database.
It is appropriate for performing various types of record linkage
and can be assessed by standard record linkage methods.